@@ -6,8 +6,6 @@ sub new {
     my $class = shift;
     my $self = { @_ };
     bless $self, $class;
-    use Data::Dumper;
-    warn Dumper $self;
     return $self;
 }
 
